.. image:: _static/logo_ga.png

==============================
GA4GH Reference Implementation
==============================

This the documentation for version |version| of the GA4GH reference
implementation.

********
Contents
********

.. toctree::
    :maxdepth: 2

    introduction
    demo
    installation
    api
    configuration
    development
    status


